import matplotlib as mpl
import matplotlib.pyplot as plt
from   matplotlib.colors import ListedColormap
import numpy as np

def draw_vertical_cross_section_1FIG(VER,FigTitle,colormap,clevels,args,\
                                     draw_top,draw_bottom,\
                                     UVALONG="N",WVER="N",maxUV=0,scaleUV=0):

    Fxsiz = 8
    Fysiz = 7
    shrink_v = 0.6
    
    fig = plt.figure(figsize=(Fxsiz,Fysiz))

    # configure for a single figure in the whole figure domain
    ax  = fig.add_subplot(111)    
    
    # limit draw range
    if(draw_top > draw_bottom + 0.01):
        VER = VER.sel(LEV=slice(draw_bottom,draw_top))
        if args.WIND is not None:
            WVER = WVER.sel(LEV=slice(draw_bottom,draw_top))
            UVALONG = UVALONG.sel(LEV=slice(draw_bottom,draw_top))

    # check P-coordinate ###########
    if VER["LEV"][1] < VER["LEV"][0]:
        print("P-coordinate")
        NZ = len(VER["LEV"])
        #axV.set_yscale("log")
        ax.set_ylim(VER["LEV"][0], VER["LEV"][NZ-1])# reverse vertical direct
        contourf = ax.contourf(VER["DISTANCE"],VER["LEV"],VER,\
                                cmap=colormap,levels=clevels,extend="both")
    else:            
        #contourf = ax.contourf(VER["DISTANCE"],VER["LEV"],VER,\
        #                   cmap=colormap,levels=clevels,extend="both")

        TMP = VER.values
        XXX = VER["DISTANCE"].values
        YYY = VER["LEV"].values
        contourf = ax.contourf(XXX,YYY,TMP,\
                               cmap=colormap,levels=clevels,\
                               extend="both")
        gray_cmap = ListedColormap([(0,0,0,0),'gray'])
        nan_mask = np.isnan(TMP).astype(int)
        extent=[XXX.min(),XXX.max(),YYY.min(),YYY.max()]
        ax.imshow(nan_mask,origin='lower',extent=extent,\
                   cmap=gray_cmap,aspect="auto")
        
    plt.colorbar(contourf,shrink=shrink_v, pad= 0.03)

    if args.WIND is not None:
       if int(args.WIND) == 0:  # vector
            Q=ax.quiver(WVER["DISTANCE"].values,WVER["LEV"].values,\
                        UVALONG,WVER,\
                        units='inches',scale=scaleUV)
            X1 = Fxsiz *0.8
            Y1 = Fysiz *0.9
            ax.quiverkey(Q,X1,Y1,maxUV,str(maxUV)+"m/s",
                         labelpos='E',coordinates='inches')
            
    # setting for xlabel and ylabel
    ax.set_xlabel("distance (km)", size=14)
    ax.set_ylabel("altitude (m)", size=14)
            
    # Draw Fig Title
    ax.set_title(FigTitle,loc="center")         

    if args.OUTFIG is not None:
        plt.savefig(args.OUTFIG)
    
    plt.show()
